@@ -5,15 +5,20 @@ class Razor::Command::DeleteNode < Razor::Command
 Remove a single node from the database.  Should the node boot again it will be
 rediscovered and treated as any other new node.
   EOT
-  example <<-EOT
+  example api: <<-EOT
 Delete the node "node17":
 
     {"name": "node17"}
   EOT
+  example cli: <<-EOT
+Delete the node "node17":
+
+    razor delete-node --name node17
+  EOT
 
   authz '%{name}'
   attr  'name', type: String, required: true, size: 1..250,
-                help: _('the name of the node to delete')
+                help: _('the name of the node to delete.')
 
   def run(request, data)
     if node = Razor::Data::Node[:name => data['name']]
