@@ -7,12 +7,18 @@ the number of nodes bound to that policy.  Any node that was installed will
 remain "installed", and will not be matched to by other policy.
   EOT
 
-  example <<-EOT
+  example api: <<-EOT
 Delete the policy "obsolete":
 
     {"name": "obsolete"}
   EOT
 
+  example cli: <<-EOT
+Delete the policy "obsolete":
+
+    razor delete-policy --name obsolete
+  EOT
+
 
   authz '%{name}'
   attr  'name', type: String, required: true, size: 1..Float::INFINITY,
