@@ -9,12 +9,18 @@ stop installing if that was triggered by matching this policy prior to the
 disable command.
   EOT
 
-  example <<-EOT
+  example api: <<-EOT
 Disable a policy:
 
     {"name": "example"}
   EOT
 
+  example cli: <<-EOT
+Disable a policy:
+
+    razor delete-policy --name example
+  EOT
+
 
   authz '%{name}'
   attr  'name', type: String, required: true, references: Razor::Data::Policy,
