@@ -7,16 +7,22 @@ This will remove a tag already present from a policy.  This change has no
 effect on nodes already bound to the policy.
   EOT
 
-  example <<-EOT
+  example api: <<-EOT
 Remove the tag `virtual` to the policy `example`:
 
     {"name": "example", "tag": "virtual"}
   EOT
 
+  example cli: <<-EOT
+Remove the tag `virtual` to the policy `example`:
+
+    razor remove-policy-tag --name example --tag virtual
+  EOT
+
   authz '%{name}:%{tag}'
 
   attr 'name', type: String, required: true, references: Razor::Data::Policy,
-               help: _('The policy to remove the tag from.')
+               help: _('The policy from which to remove the tag.')
 
   attr 'tag', type: String, required: true, size: 1..Float::INFINITY,
               help: _('The tag to remove from the policy.')
