@@ -9,7 +9,7 @@ node is observed to be in a different power state an IPMI command will be
 issued to change to the desired state.
   EOT
 
-  example <<-EOT
+  example api: <<-EOT
 Setting the power state for the node:
 
     {
@@ -18,9 +18,16 @@ Setting the power state for the node:
     }
   EOT
 
+  example cli: <<-EOT
+Setting the power state for the node:
+
+    razor set-node-desired-power-state --name node1234 \\
+        --to on|off|null
+  EOT
+
   authz '%{name}'
   attr  'name', type: String, required: true,  references: Razor::Data::Node,
-                help: _('The node to change the desired power state of.')
+                help: _('The node for which to change the desired power state.')
 
   attr 'to', type: String, required: false, one_of: ['on', 'off', nil],
              help: _('The desired power state -- on, or off.')
