@@ -21,9 +21,9 @@ Set IPMI credentials for node 'node17':
 
     {
       "name":          "node17",
-      "ipmi-hostname": "bmc17.example.com",
-      "ipmi-username": null,
-      "ipmi-password": "sekretskwirrl"
+      "ipmi_hostname": "bmc17.example.com",
+      "ipmi_username": null,
+      "ipmi_password": "sekretskwirrl"
     }
   EOT
 
@@ -40,13 +40,13 @@ Set IPMI credentials for node 'node17':
   attr  'name', type: String, required: true, references: Razor::Data::Node,
                 help: _('The node on which to set IPMI credentials.')
 
-  attr 'ipmi-hostname', type: String, size: 1..255,
+  attr 'ipmi_hostname', type: String, size: 1..255,
                         help: _('The IPMI hostname or IP address of the BMC of this host.')
 
-  attr 'ipmi-username', type: String, also: 'ipmi-hostname', size: 1..32,
+  attr 'ipmi_username', type: String, also: 'ipmi_hostname', size: 1..32,
                         help: _('The IPMI LANPLUS username, if any, for this BMC.')
 
-  attr 'ipmi-password', type: String, also: 'ipmi-hostname', size: 1..20,
+  attr 'ipmi_password', type: String, also: 'ipmi_hostname', size: 1..20,
                         help: _('The IPMI LANPLUS password, if any, for this BMC.')
 
   def run(request, data)
@@ -58,9 +58,9 @@ Set IPMI credentials for node 'node17':
     # change that (because, say, we fix the -/_ thing globally, make sure
     # you restrict this to changing the specific attributes only.
     node.update(
-      :ipmi_hostname => data['ipmi-hostname'],
-      :ipmi_username => data['ipmi-username'],
-      :ipmi_password => data['ipmi-password'])
+      :ipmi_hostname => data['ipmi_hostname'],
+      :ipmi_username => data['ipmi_username'],
+      :ipmi_password => data['ipmi_password'])
 
     { :result => _('updated IPMI details') }
   end
