@@ -291,8 +291,17 @@ module Razor::Data
       if data['update']
         data['update'].is_a? Hash or raise ArgumentError, _('update must be a hash')
         replace = (not [true, 'true'].include?(data['no_replace']))
+
         data['update'].each do |k,v|
-          new_metadata[k] = v if replace or not new_metadata[k]
+          if replace or not new_metadata[k]
+            begin
+              # If the value is valid json, parse it and store as structured
+              new_metadata[k] = JSON::parse(v)
+            rescue
+              # Otherwise just store the data as is.
+              new_metadata[k] = v
+            end
+          end
         end
       end
       if data['remove']
@@ -362,7 +371,7 @@ module Razor::Data
         # independent of the order in which the BIOS enumerates NICs. We
         # also don't care about case
         k = "mac" if k =~ /net[0-9]+/
-        [k.downcase, v.strip.downcase]
+        [k.downcase, v.strip.downcase.gsub(":", "-")]
       end.select do |k, _|
         Razor::Config::HW_INFO_KEYS.include?(k) || k.start_with?('fact_')
       end.sort do |a, b|
@@ -484,7 +493,7 @@ module Razor::Data
       node.boot_count += 1
       if name == "finished" and node.policy
         node.installed = node.policy.name
-        Razor::Data::Hook.run('node-install-finished', node: self)
+        Razor::Data::Hook.run('node-install-finished', node: node)
       end
       node.save
     end
